@@ -4,7 +4,7 @@ package POE::Component::ElasticSearch::Indexer;
 use strict;
 use warnings;
 
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use Const::Fast;
 use Digest::SHA1 qw(sha1_hex);
@@ -115,7 +115,7 @@ sub spawn {
     DEBUG(sprintf "Spawned an HTTP Pool for %d servers: %d max connections, %d max per host.",
         $num_servers, @CONFIG{qw(MaxConnsTotal MaxConnsPerServer)}
     );
-    return;
+    return $session;
 }
 
 #------------------------------------------------------------------------#
@@ -575,7 +575,7 @@ POE::Component::ElasticSearch::Indexer - POE session to index data to ElasticSea
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
